@@ -16,8 +16,8 @@ from .. import (
     DevEnvironmentOptions as _DevEnvironmentOptions_b10d89d1,
     IDevEnvironment as _IDevEnvironment_9a084622,
     Project as _Project_57d89203,
+    Task as _Task_9fa875b6,
 )
-from ..tasks import Task as _Task_fb843092
 
 
 @jsii.implements(_IDevEnvironment_9a084622)
@@ -40,7 +40,7 @@ class DevContainer(
         *,
         docker_image: typing.Optional[_DevEnvironmentDockerImage_4a8d8ffd] = None,
         ports: typing.Optional[typing.Sequence[builtins.str]] = None,
-        tasks: typing.Optional[typing.Sequence[_Task_fb843092]] = None,
+        tasks: typing.Optional[typing.Sequence[_Task_9fa875b6]] = None,
         vscode_extensions: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
         '''
@@ -82,7 +82,7 @@ class DevContainer(
         return typing.cast(None, jsii.invoke(self, "addPorts", [*ports]))
 
     @jsii.member(jsii_name="addTasks")
-    def add_tasks(self, *tasks: _Task_fb843092) -> None:
+    def add_tasks(self, *tasks: _Task_9fa875b6) -> None:
         '''(experimental) Adds tasks to run when the container starts.
 
         Tasks will be run in sequence.
@@ -129,7 +129,7 @@ class DevContainerOptions(_DevEnvironmentOptions_b10d89d1):
         *,
         docker_image: typing.Optional[_DevEnvironmentDockerImage_4a8d8ffd] = None,
         ports: typing.Optional[typing.Sequence[builtins.str]] = None,
-        tasks: typing.Optional[typing.Sequence[_Task_fb843092]] = None,
+        tasks: typing.Optional[typing.Sequence[_Task_9fa875b6]] = None,
         vscode_extensions: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
         '''(experimental) Constructor options for the DevContainer component.
@@ -173,13 +173,13 @@ class DevContainerOptions(_DevEnvironmentOptions_b10d89d1):
         return typing.cast(typing.Optional[typing.List[builtins.str]], result)
 
     @builtins.property
-    def tasks(self) -> typing.Optional[typing.List[_Task_fb843092]]:
+    def tasks(self) -> typing.Optional[typing.List[_Task_9fa875b6]]:
         '''(experimental) An array of tasks that should be run when the container starts.
 
         :stability: experimental
         '''
         result = self._values.get("tasks")
-        return typing.cast(typing.Optional[typing.List[_Task_fb843092]], result)
+        return typing.cast(typing.Optional[typing.List[_Task_9fa875b6]], result)
 
     @builtins.property
     def vscode_extensions(self) -> typing.Optional[typing.List[builtins.str]]:
